@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2023 Martin Donath <martin.donath@squidfunk.com>
+ * Copyright (c) 2016-2024 Martin Donath <martin.donath@squidfunk.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -28,9 +28,11 @@ export * from "./dialog"
 export * from "./header"
 export * from "./main"
 export * from "./palette"
+export * from "./progress"
 export * from "./search"
 export * from "./sidebar"
 export * from "./source"
 export * from "./tabs"
 export * from "./toc"
+export * from "./tooltip"
 export * from "./top"
